@@ -17,6 +17,14 @@ print.Pred <- function(obj){
 #' @export
 Predication <- function(P,A,m,k,tvectors=tvectors,breakdown=FALSE,norm="none"){
   
+  if(class(tvectors) == "data.frame"){
+    tvectors <- as.matrix(tvectors)
+  }else if(class(tvectors) == "textmatrix"){
+    tvectors <- matrix(tvectors,
+                       nrow=nrow(tvectors),ncol=ncol(tvectors),
+                       dimnames=list(rownames(tvectors),colnames(tvectors)))
+  }
+  
   if(class(tvectors) == "matrix"){
     
     if(breakdown==TRUE){
