@@ -6,6 +6,14 @@
 choose.target <- function(x,lower,upper,n,tvectors=tvectors,
                           breakdown=FALSE){
   
+  if(class(tvectors) == "data.frame"){
+    tvectors <- as.matrix(tvectors)
+  }else if(class(tvectors) == "textmatrix"){
+    tvectors <- matrix(tvectors,
+                       nrow=nrow(tvectors),ncol=ncol(tvectors),
+                       dimnames=list(rownames(tvectors),colnames(tvectors)))
+  }
+  
   if(class(tvectors) == "matrix"){ 
     
     allwords <- vector(length=nrow(tvectors))
